==> jpmml-sklearn-1.2.6-sources.jar: sklearn/Selector.java <==
/*
 * Copyright (c) 2016 Villu Ruusmann
 *
 * This file is part of JPMML-SkLearn
 *
 * JPMML-SkLearn is free software: you can redistribute it and/or modify
 * it under the terms of the GNU Affero General Public License as published by
 * the Free Software Foundation, either version 3 of the License, or
 * (at your option) any later version.
 *
 * JPMML-SkLearn is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU Affero General Public License for more details.
 *
 * You should have received a copy of the GNU Affero General Public License
 * along with JPMML-SkLearn.  If not, see <http://www.gnu.org/licenses/>.
 */
package sklearn;

import java.util.ArrayList;
import java.util.List;

import org.dmg.pmml.DataType;
import org.dmg.pmml.OpType;
import org.jpmml.converter.Feature;
import org.jpmml.sklearn.ClassDictUtil;
import org.jpmml.sklearn.SkLearnEncoder;

abstract
public class Selector extends Transformer implements HasNumberOfFeatures {

	public Selector(String module, String name){
		super(module, name);
	}

	abstract
	public List<Boolean> getSupportMask();

	@Override
	public OpType getOpType(){
		return null;
	}

	@Override
	public DataType getDataType(){
		return null;
	}

	@Override
	public List<Feature> encodeFeatures(List<String> ids, List<Feature> features, SkLearnEncoder encoder){
		List<Boolean> supportMask = getSupportMask();

		if(supportMask == null){
			return features;
		}

		ClassDictUtil.checkSize(supportMask, ids, features);

		List<String> selectedIds = new ArrayList<>();
		List<Feature> selectedFeatures = new ArrayList<>();

		for(int i = 0; i < supportMask.size(); i++){

			if(supportMask.get(i)){
				selectedIds.add(ids.get(i));
				selectedFeatures.add(features.get(i));
			}
		}

		ids.clear();

		if(selectedIds.size() > 0){
			ids.addAll(selectedIds);
		}

		return selectedFeatures;
	}
}

==> jpmml-sklearn-1.3.0-sources.jar: sklearn/Selector.java <==
/*
 * Copyright (c) 2016 Villu Ruusmann
 *
 * This file is part of JPMML-SkLearn
 *
 * JPMML-SkLearn is free software: you can redistribute it and/or modify
 * it under the terms of the GNU Affero General Public License as published by
 * the Free Software Foundation, either version 3 of the License, or
 * (at your option) any later version.
 *
 * JPMML-SkLearn is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU Affero General Public License for more details.
 *
 * You should have received a copy of the GNU Affero General Public License
 * along with JPMML-SkLearn.  If not, see <http://www.gnu.org/licenses/>.
 */
package sklearn;

import java.util.ArrayList;
import java.util.List;

import org.dmg.pmml.DataType;
import org.dmg.pmml.OpType;
import org.jpmml.converter.Feature;
import org.jpmml.sklearn.ClassDictUtil;
import org.jpmml.sklearn.SkLearnEncoder;

abstract
public class Selector extends Transformer implements HasNumberOfFeatures {

	public Selector(String module, String name){
		super(module, name);
	}

	abstract
	public List<Boolean> getSupportMask();

	@Override
	public OpType getOpType(){
		return null;
	}

	@Override
	public DataType getDataType(){
		return null;
	}

	@Override
	public List<Feature> encodeFeatures(List<Feature> features, SkLearnEncoder encoder){
		List<Boolean> supportMask = getSupportMask();

		if(supportMask == null){
			return features;
		}

		ClassDictUtil.checkSize(features, supportMask);

		List<Feature> result = new ArrayList<>();

		for(int i = 0; i < features.size(); i++){
			Feature feature = features.get(i);

			if(supportMask.get(i)){
				result.add(feature);
			}
		}

		return result;
	}
}
